# Gaussian and Binomial Distribution Package

This package has been developed during my studies towards the completion of Udacity's Machine Learning Nanodegree.
The aim of the software engineering training was to initiate learners to coding best practices (code refactoring, code reviews, packaging, testing, logging, OOP)

I hope this will be useful for future learners.